==> opigno_lms-7.x-1.27-no-core.tar.gz: opigno_lms/modules/contrib/h5p/modules/h5peditor/h5peditor/language/nl.js <==
H5PEditor.language.core = {
  missingTranslation: '[Vertaling ontbreekt :key]',
  loading: 'Laden, wachten alstublieft ...',
  selectLibrary: 'Selecteer de library die je wilt gebruiken voor je content.',
  unknownFieldPath: 'Kon ":path" niet vinden.',
  notImageField: '":path" is geen afbeelding.',
  notImageOrDimensionsField: '":path" is geen afbeelding of een veld voor afmetingen.',
  requiredProperty: 'De :property is vereist en moet een waarde hebben.',
  onlyNumbers: 'De :property waarde mag alleen cijfers bevatten.',
  exceedsMax: 'De :property waarde is hoger dan het maximum :max.',
  listExceedsMax: 'De lijst is groter dan het maximum van :max items.',
  belowMin: 'De :property waarde is lager dan het minimum :min.',
  listBelowMin: 'De lijst moet ten minste :min items bevatten voor het correct werken van de content.',
  outOfStep: 'De :property waarde kan alleen worden gewijzigd in stappen van :step.',
  add: 'Toevoegen',
  addFile: 'Voeg bestand toe',
  removeFile: 'Verwijder bestand',
  confirmRemoval: 'Weet je zeker dat je dit :type wilt verwijderen?',
  removeImage: 'Verwijder afbeelding',
  confirmImageRemoval: 'Hiermee wordt je afbeelding verwijderd. Weet je zeker dat je wilt verdergaan?',
  changeFile: 'Wijzig bestand',
  changeLibrary: 'Content type wijzigen?',
  semanticsError: 'Semantics fout: :error',
  missingProperty: 'Veld :index mist :property eigenschap.',
  expandCollapse: 'Uitvouwen/Invouwen',
  addEntity: 'Voeg :entity toe',
  tooLong: 'Veldwaarde is te lang, mag :max letters of minder bevatten.',
  invalidFormat: 'Veldwaarde bevat een ongeldig format of karakters die verboden zijn.',
  confirmChangeLibrary: 'Hierdoor verlies je al het werk dat je met het huidige content type hebt gedaan. Weet je zeker dat je het content type wilt wijzigen?',
  commonFields: 'Tekst overschrijven en vertalingen',
  commonFieldsDescription: 'Hier kun je instellingen bewerken of in dit content type gebruikte teksten vertalen.',
  uploading: 'Uploaden, wachten alstublieft ...',
  noFollow: 'Kan veld ":path" niet volgen.',
  editCopyright: 'Copyright bewerken',
  close: 'Sluiten',
  tutorial: 'Tutorial beschikbaar',
  example: 'Example',
  editMode: 'Bewerkmodus',
  listLabel: 'Lijst',
  uploadError: 'Fout bij uploaden bestand',
  fileToLarge: 'Het bestand dat je probeert te uploaden kan te groot zijn.',
  unknownFileUploadError: 'Onbekende fout bij uploaden bestand',
  noSemantics: 'Fout, kon het content type formulier niet laden.',
  editImage: 'Afbeelding bewerken',
  saveLabel: 'Opslaan',
  cancelLabel: 'Annuleren',
  resetToOriginalLabel: 'Terugzetten naar oorspronkelijk',
  loadingImageEditor: 'Afbeeldingseditor laden, wachten alstublieft ...',
  selectFiletoUpload: 'Selecteer bestand om te uploaden',
  or: 'of',
  enterAudioUrl: 'Voer audio bron URL in',
  enterVideoUrl: 'Voer video bron URL of YouTube link in',
  enterAudioTitle: 'Paste link or other audio source URL',
  enterVideoTitle: 'Paste YouTube link or other video source URL',
  uploadAudioTitle: 'Upload audio file',
  uploadVideoTitle: 'Upload video file',
  addVideoDescription: 'H5P ondersteunt alle externe videobronnen met format mp4, webm of ogv, zoals Vimeo Pro, en biedt ondersteuning voor YouTube links.',
  insert: 'Invoegen',
  cancel: 'Annuleren',
  height: 'hoogte',
  width: 'breedte',
  textField: 'tekstveld',
  numberField: 'getalveld',
  orderItemUp: 'Oplopend sorteren',
  orderItemDown: 'Aflopend sorteren',
  removeItem: 'Item verwijderen',
  hubPanelLabel: 'Selecteer content type',
  importantInstructions: 'Belangrijke instructies',
  showImportantInstructions: 'Show instructions',
  hideImportantInstructions: 'Verberg belangrijke instructies',
  hide: 'Verberg',
  example: 'Voorbeeld',
  createContentTabLabel: 'Creëer content',
  uploadTabLabel: 'Uploaden',
  uploadPlaceholder: 'Geen bestand gekozen',
  uploadInstructionsTitle: 'Een H5P bestand uploaden.',
  uploadInstructionsContent: 'Je kunt beginnen met voorbeelden van <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'Upload een bestand',
  uploadFileButtonChangeLabel: 'Wijzig bestand',
  uploadingThrobber: 'Uploaden...',
  h5pFileWrongExtensionTitle: 'Het geselecteerde bestand kon niet worden geüpload',
  h5pFileWrongExtensionContent: 'Alleen bestanden met de .h5p extensie toegestaan.',
  h5pFileValidationFailedTitle: 'Kon het H5P bestand niet valideren.',
  h5pFileValidationFailedContent: 'Zorg ervoor dat de geüploade H5P geldige H5P content bevat. H5P' +
  ' bestanden die alleen bibliotheken bevatten, dienen te worden geüpload via de H5P Bibliotheken pagina.',
  h5pFileUploadServerErrorTitle: 'Het H5P bestand kon niet worden geüpload',
  h5pFileUploadServerErrorContent: 'Er is een onverwachte fout opgetreden. Controleer het server log voor' +
  ' meer informatie.',
  contentTypeSectionAll: 'Alle',
  contentTypeSectionMine: 'Mijn Content Types',
  contentTypeSectionPopular: 'Meest populair',
  contentTypeSectionTitle: 'Blader door content types',
  contentTypeSearchFieldPlaceholder: 'Zoeken naar Content Types',
  contentTypeInstallButtonLabel: 'Installeren',
  contentTypeInstallingButtonLabel: 'Bezig met installeren',
  contentTypeUseButtonLabel: 'Gebruik',
  contentTypeUpdateButtonLabel: 'Updaten',
  contentTypeUpdatingButtonLabel: 'Bezig met updaten',
  contentTypeGetButtonLabel: 'Ophalen',
  contentTypeBackButtonLabel: 'Terug',
  contentTypeIconAltText: 'Icoon',
  contentTypeInstallSuccess: ':contentType succesvol geïnstalleerd!',
  contentTypeUpdateSuccess: ':contentType succesvol geüpdatet!',
  contentTypeInstallError: ':contentType kon niet worden geïnstalleerd. Neem contact op met je site beheerder.',
  contentTypeLicensePanelTitle: 'Licentie',
  contentTypeDemoButtonLabel: 'Content Demo',
  readMore: 'Meer lezen',
  readLess: 'Minder lezen',
  contentTypeOwner: 'Door :owner',
  contentTypeUnsupportedApiVersionTitle: 'Dit content type vereist een nieuwere core versie',
  contentTypeUnsupportedApiVersionContent: 'Neem contact op met je site beheerder voor de benodigde updates',
  contentTypeUpdateAvailable: 'Update beschikbaar',
  contentTypeRestricted: 'Beperkt content type',
  contentTypeRestrictedDesc: 'Het gebruik van dit content type is beperkt door een site beheerder.',
  contentTypeNotInstalled: 'Content type niet geïnstalleerd',
  contentTypeNotInstalledDesc: 'Je hebt geen toestemming om content types te installeren.',
  theContentType: 'het content type',
  currentMenuSelected: 'huidige selectie',
  errorCommunicatingHubTitle: 'Kan niet communiceren met hub.',
  errorCommunicatingHubContent: 'Er is een fout opgetreden. Probeer het opnieuw.',
  warningNoContentTypesInstalled: "Je hebt geen geïnstalleerde content types.",
  warningChangeBrowsingToSeeResults: 'Klik <em>Alle</em> om de lijst op te halen van alle content types die je kunt installeren.',
  warningUpdateAvailableTitle: 'Er is een nieuwe versie van :contentType beschikbaar.',
  warningUpdateAvailableBody: 'Update naar de laatste versie voor een verbeterde ervaring.',
  licenseDescription: 'Sommige van de kenmerken van deze licentie zijn hieronder weergegeven. Klik op het info icoon hierboven om de oorspronkelijke tekst van de licentie te lezen.',
  licenseModalTitle: 'Details van licentie',
  licenseModalSubtitle: 'Selecteer een licentie om informatie te krijgen over het correcte gebruik ervan',
  licenseUnspecified: 'Niet gespecificeerd',
  licenseCanUseCommercially: 'Mag commercieel gebruiken',
  licenseCanModify: 'Mag aanpassen',
  licenseCanDistribute: 'Mag distribueren',
  licenseCanSublicense: 'Mag sublicenties verstrekken',
  licenseCanHoldLiable: 'Mag aansprakelijk houden',
  licenseCannotHoldLiable: 'Mag niet aansprakelijk houden',
  licenseMustIncludeCopyright: 'Moet copyright bijvoegen',
  licenseMustIncludeLicense: 'Moet licentie bijvoegen',
  licenseFetchDetailsFailed: 'Details van licentie ophalen mislukt',
  imageLightboxTitle: 'Afbeeldingen',
  imageLightBoxProgress: ':num van :total',
  nextImage: 'Volgende afbeelding',
  previousImage: 'Vorige afbeelding',
  screenshots: 'Screenshots',
  reloadButtonLabel: 'Opnieuw laden',
  videoQuality: 'Video quality label',
  videoQualityDescription: 'This label helps the user identify the current quality of the video. E.g. 1080p, 720p, HD or Mobile',
  videoQualityDefaultLabel: 'Quality :index'
};

==> opigno_lms-7.x-1.29-no-core.tar.gz: opigno_lms/modules/contrib/h5p/modules/h5peditor/h5peditor/language/nl.js <==
H5PEditor.language.core = {
  missingTranslation: '[Vertaling ontbreekt :key]',
  loading: 'Laden, wachten alstublieft ...',
  selectLibrary: 'Selecteer de library die je wilt gebruiken voor je content.',
  unknownFieldPath: 'Kon ":path" niet vinden.',
  notImageField: '":path" is geen afbeelding.',
  notImageOrDimensionsField: '":path" is geen afbeelding of een veld voor afmetingen.',
  requiredProperty: 'De :property is vereist en moet een waarde hebben.',
  onlyNumbers: 'De :property waarde mag alleen cijfers bevatten.',
  exceedsMax: 'De :property waarde is hoger dan het maximum :max.',
  listExceedsMax: 'De lijst is groter dan het maximum van :max items.',
  belowMin: 'De :property waarde is lager dan het minimum :min.',
  listBelowMin: 'De lijst moet ten minste :min items bevatten voor het correct werken van de content.',
  outOfStep: 'De :property waarde kan alleen worden gewijzigd in stappen van :step.',
  add: 'Toevoegen',
  addFile: 'Voeg bestand toe',
  removeFile: 'Verwijder bestand',
  confirmRemoval: 'Weet je zeker dat je dit :type wilt verwijderen?',
  removeImage: 'Verwijder afbeelding',
  confirmImageRemoval: 'Hiermee wordt je afbeelding verwijderd. Weet je zeker dat je wilt verdergaan?',
  changeFile: 'Wijzig bestand',
  changeLibrary: 'Content type wijzigen?',
  semanticsError: 'Semantics fout: :error',
  missingProperty: 'Veld :index mist :property eigenschap.',
  expandCollapse: 'Uitvouwen/Invouwen',
  addEntity: 'Voeg :entity toe',
  tooLong: 'Veldwaarde is te lang, mag :max letters of minder bevatten.',
  invalidFormat: 'Veldwaarde bevat een ongeldig format of karakters die verboden zijn.',
  confirmChangeLibrary: 'Hierdoor verlies je al het werk dat je met het huidige content type hebt gedaan. Weet je zeker dat je het content type wilt wijzigen?',
  commonFields: 'Tekst overschrijven en vertalingen',
  commonFieldsDescription: 'Hier kun je instellingen bewerken of in dit content type gebruikte teksten vertalen.',
  uploading: 'Uploaden, wachten alstublieft ...',
  noFollow: 'Kan veld ":path" niet volgen.',
  editCopyright: 'Copyright bewerken',
  close: 'Sluiten',
  tutorial: 'Tutorial beschikbaar',
  example: 'Example',
  editMode: 'Bewerkmodus',
  listLabel: 'Lijst',
  uploadError: 'Fout bij uploaden bestand',
  fileToLarge: 'Het bestand dat je probeert te uploaden kan te groot zijn.',
  unknownFileUploadError: 'Onbekende fout bij uploaden bestand',
  noSemantics: 'Fout, kon het content type formulier niet laden.',
  editImage: 'Afbeelding bewerken',
  saveLabel: 'Opslaan',
  cancelLabel: 'Annuleren',
  resetToOriginalLabel: 'Terugzetten naar oorspronkelijk',
  loadingImageEditor: 'Afbeeldingseditor laden, wachten alstublieft ...',
  selectFiletoUpload: 'Selecteer bestand om te uploaden',
  or: 'of',
  enterAudioUrl: 'Voer audio bron URL in',
  enterVideoUrl: 'Voer video bron URL of YouTube link in',
  enterAudioTitle: 'Paste link or other audio source URL',
  enterVideoTitle: 'Paste YouTube link or other video source URL',
  uploadAudioTitle: 'Upload audio file',
  uploadVideoTitle: 'Upload video file',
  addVideoDescription: 'H5P ondersteunt alle externe videobronnen met format mp4, webm of ogv, zoals Vimeo Pro, en biedt ondersteuning voor YouTube links.',
  insert: 'Invoegen',
  cancel: 'Annuleren',
  height: 'hoogte',
  width: 'breedte',
  textField: 'tekstveld',
  numberField: 'getalveld',
  orderItemUp: 'Oplopend sorteren',
  orderItemDown: 'Aflopend sorteren',
  removeItem: 'Item verwijderen',
  hubPanelLabel: 'Selecteer content type',
  importantInstructions: 'Belangrijke instructies',
  showImportantInstructions: 'Show instructions',
  hideImportantInstructions: 'Verberg belangrijke instructies',
  hide: 'Verberg',
  example: 'Voorbeeld',
  createContentTabLabel: 'Creëer content',
  uploadTabLabel: 'Uploaden',
  uploadPlaceholder: 'Geen bestand gekozen',
  uploadInstructionsTitle: 'Een H5P bestand uploaden.',
  uploadInstructionsContent: 'Je kunt beginnen met voorbeelden van <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'Upload een bestand',
  uploadFileButtonChangeLabel: 'Wijzig bestand',
  uploadingThrobber: 'Uploaden...',
  uploadSuccess: ':title was successfully uploaded!',
  unableToInterpretError: 'Unable to interpret response.',
  unableToInterpretSolution: 'Please check your error log.',
  h5pFileWrongExtensionTitle: 'Het geselecteerde bestand kon niet worden geüpload',
  h5pFileWrongExtensionContent: 'Alleen bestanden met de .h5p extensie toegestaan.',
  h5pFileValidationFailedTitle: 'Kon het H5P bestand niet valideren.',
  h5pFileValidationFailedContent: 'Zorg ervoor dat de geüploade H5P geldige H5P content bevat. H5P' +
  ' bestanden die alleen bibliotheken bevatten, dienen te worden geüpload via de H5P Bibliotheken pagina.',
  h5pFileUploadServerErrorTitle: 'Het H5P bestand kon niet worden geüpload',
  h5pFileUploadServerErrorContent: 'Er is een onverwachte fout opgetreden. Controleer het server log voor' +
  ' meer informatie.',
  contentTypeSectionAll: 'Alle Content Types',
  searchResults: 'Search Results',
  contentTypeSearchFieldPlaceholder: 'Zoeken naar Content Types',
  contentTypeInstallButtonLabel: 'Installeren',
  contentTypeInstallingButtonLabel: 'Bezig met installeren',
  contentTypeUseButtonLabel: 'Gebruik',
  contentTypeDetailButtonLabel: 'Details',
  contentTypeUpdateButtonLabel: 'Updaten',
  contentTypeUpdatingButtonLabel: 'Bezig met updaten',
  contentTypeGetButtonLabel: 'Ophalen',
  contentTypeBackButtonLabel: 'Terug',
  contentTypeIconAltText: 'Icoon',
  contentTypeInstallSuccess: ':contentType succesvol geïnstalleerd!',
  contentTypeUpdateSuccess: ':contentType succesvol geüpdatet!',
  contentTypeInstallError: ':contentType kon niet worden geïnstalleerd. Neem contact op met je site beheerder.',
  contentTypeLicensePanelTitle: 'Licentie',
  contentTypeDemoButtonLabel: 'Content Demo',
  numResults: ':num results',
  show: 'Show',
  recentlyUsedFirst: 'Recently Used First',
  popularFirst: 'Popular First',
  newestFirst: 'Newest First',
  aToZ: 'A to Z',
  noResultsFound: 'No results found',
  noResultsFoundDesc: 'There is no content type that matches your search criteria.',
  readMore: 'Meer lezen',
  readLess: 'Minder lezen',
  contentTypeOwner: 'Door :owner',
  contentTypeUnsupportedApiVersionTitle: 'Dit content type vereist een nieuwere core versie',
  contentTypeUnsupportedApiVersionContent: 'Neem contact op met je site beheerder voor de benodigde updates',
  contentTypeUpdateAvailable: 'Update beschikbaar',
  contentTypeRestricted: 'Beperkt content type',
  contentTypeRestrictedDesc: 'Het gebruik van dit content type is beperkt door een site beheerder.',
  contentTypeNotInstalled: 'Content type niet geïnstalleerd',
  contentTypeNotInstalledDesc: 'Je hebt geen toestemming om content types te installeren.',
  theContentType: 'het content type',
  currentMenuSelected: 'huidige selectie',
  errorCommunicatingHubTitle: 'Kan niet communiceren met hub.',
  errorCommunicatingHubContent: 'Er is een fout opgetreden. Probeer het opnieuw.',
  warningNoContentTypesInstalled: "Je hebt geen geïnstalleerde content types.",
  warningChangeBrowsingToSeeResults: 'Klik <em>Alle</em> om de lijst op te halen van alle content types die je kunt installeren.',
  warningUpdateAvailableTitle: 'Er is een nieuwe versie van :contentType beschikbaar.',
  warningUpdateAvailableBody: 'Update naar de laatste versie voor een verbeterde ervaring.',
  licenseDescription: 'Sommige van de kenmerken van deze licentie zijn hieronder weergegeven. Klik op het info icoon hierboven om de oorspronkelijke tekst van de licentie te lezen.',
  licenseModalTitle: 'Details van licentie',
  licenseModalSubtitle: 'Selecteer een licentie om informatie te krijgen over het correcte gebruik ervan',
  licenseUnspecified: 'Niet gespecificeerd',
  licenseCanUseCommercially: 'Mag commercieel gebruiken',
  licenseCanModify: 'Mag aanpassen',
  licenseCanDistribute: 'Mag distribueren',
  licenseCanSublicense: 'Mag sublicenties verstrekken',
  licenseCanHoldLiable: 'Mag aansprakelijk houden',
  licenseCannotHoldLiable: 'Mag niet aansprakelijk houden',
  licenseMustIncludeCopyright: 'Moet copyright bijvoegen',
  licenseMustIncludeLicense: 'Moet licentie bijvoegen',
  licenseFetchDetailsFailed: 'Details van licentie ophalen mislukt',
  imageLightboxTitle: 'Afbeeldingen',
  imageLightBoxProgress: ':num van :total',
  nextImage: 'Volgende afbeelding',
  previousImage: 'Vorige afbeelding',
  screenshots: 'Screenshots',
  reloadButtonLabel: 'Opnieuw laden',
  videoQuality: 'Video quality label',
  videoQualityDescription: 'This label helps the user identify the current quality of the video. E.g. 1080p, 720p, HD or Mobile',
  videoQualityDefaultLabel: 'Quality :index',
  noContentTypesAvailable: 'No content types are available',
  noContentTypesAvailableDesc: 'Your site is having difficulties connecting to H5P.org and listing the available content types.',
  contentTypeCacheOutdated: 'Content type list outdated',
  contentTypeCacheOutdatedDesc: 'Your site is having difficulties connecting to H5P.org to check for content type updates. You may not be able to update or install new content types.',
  tryAgain: 'Try again'
};
